@@ -5,7 +5,7 @@ import pandas as pd
 import os
 from time import sleep
 
-versionNo = "0.1.5"
+versionNo = "0.1.6"
 
 controlEndpoint = "tcp://127.0.0.1:5557"
 dataEndpoint = "tcp://127.0.0.1:5556"
@@ -350,7 +350,7 @@ class eventHandler():
                     bias.busy = False
                 if contents["stimulusType"]=="gas":
                     gas.busy = False
-            if contents["$type"] == "data.event.profileController.stateChanged": #deze moet ook anders heten
+            elif contents["$type"] == "data.event.profileController.stateChanged": #deze moet ook anders heten
                 print("[PROFILE CONTROLLER]:",contents['state'])
             elif contents["$type"] == "data.event.popupRaised":
                 print("[IMPULSE POPUP]:",contents['message'])
